@@ -4,7 +4,7 @@ package DBIx::SearchBuilder;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = "1.31";
+$VERSION = "1.32";
 
 =head1 NAME
 
@@ -58,7 +58,7 @@ You can try to override just about every other method here, as long as you think
 are doing.
 
 =head1 METHOD NAMING
- 
+
 Each method has a lower case alias; '_' is used to separate words.
 For example, the method C<RedoSearch> has the alias C<redo_search>.
 
@@ -168,8 +168,6 @@ sub _Handle {
     return ( $self->{'DBIxHandle'} );
 }
 
-
-    
 =head2 _DoSearch
 
 This internal private method actually executes the search on the database;
@@ -281,7 +279,6 @@ sub _ApplyLimits {
 This routine takes a reference to a scalar containing an SQL statement. 
 It massages the statement to ensure a distinct result set is returned.
 
-
 =cut
 
 sub _DistinctQuery {
@@ -298,8 +295,6 @@ sub _DistinctQuery {
     }
 }
 
-
-
 =head2 _BuildJoins
 
 Build up all of the joins we need to perform this query.
@@ -650,6 +645,11 @@ STARTSWITH is like LIKE, except it only appends a % at the end of the string
 
 ENDSWITH is like LIKE, except it prepends a % to the beginning of the string
 
+=item "MATCHES"
+
+MATCHES is equivalent to the database's LIKE -- that is, it's actually LIKE, but
+doesn't surround the string in % signs as LIKE does.
+
 =back
 
 =item ENTRYAGGREGATOR 
@@ -699,7 +699,9 @@ sub Limit {
         elsif ( $args{'OPERATOR'} =~ /ENDSWITH/i ) {
             $args{'VALUE'}    = "%" . $args{'VALUE'};
             $args{'OPERATOR'} = "LIKE";
-        }
+        } 
+	
+	$args{'OPERATOR'} =~ s/MATCHES/LIKE/i;  # MATCHES becomes LIKE, with no % stuff
 
         #if we're explicitly told not to to quote the value or
         # we're doing an IS or IS NOT (null), don't quote the operator.
@@ -1501,7 +1503,7 @@ sub Columns {
 
 
 =head2 Fields TABLE
- 
+
 Return a list of fields in TABLE, lowercased.
 
 TODO: Why are they lowercased?
